@@ -1,4 +1,4 @@
-# Copyright (C) 2019-2021, TomTom (http://tomtom.com).
+# Copyright (C) 2019, TomTom (http://tomtom.com).
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,6 @@
 """Support for parsing python documentation."""
 
 import string
-
 from typing import List, Optional
 
 from .language_traits import LanguageTraits, TokenCategory
@@ -42,28 +41,13 @@ class PythonTraits(LanguageTraits):
     ALLOWED_SUFFIXES = None
     ALLOWED_NAMES = TokenCategory.WHITESPACE, TokenCategory.NAME,
 
+    NESTING_BOUNDARY = "["
+    NAMESPACE_SEPARATOR = "."
+
     @classmethod
     def cleanup_name(cls, name: str) -> str:
         return name.replace("::", ".").replace('"', "").strip()
 
-    @classmethod
-    def short_name(cls, name: str) -> str:
-        return name.split(".")[-1]
-
-    @classmethod
-    def full_name(cls, name: str, parent: str = "", kind: Optional[str] = None) -> str:
-        if not parent or name.startswith(f"{parent}."):
-            return name
-        return f"{parent}.{name}"
-
-    @classmethod
-    def namespace(cls, full_name: str, kind: Optional[str] = None) -> Optional[str]:
-        if "." in full_name:
-            namespace, _ = full_name.rsplit(".", maxsplit=1)
-            return namespace
-        else:
-            return None
-
 
 class PythonTypeParser(TypeParser):
     """Parser for python types."""
