@@ -26,6 +26,7 @@ from asciidoxy.generator.context import InsertData, StackFrame
 from asciidoxy.generator.errors import (
     AmbiguousReferenceError,
     ConsistencyError,
+    DuplicateIncludeError,
     IncludeFileNotFoundError,
     IncompatibleVersionError,
     InvalidApiCallError,
@@ -94,7 +95,7 @@ def test_insert_class_explicit_all(generating_api):
 
 def test_insert_cpp_class_with_leveloffset(generating_api):
     result = generating_api.insert("asciidoxy::geometry::Coordinate", leveloffset="+3")
-    assert "==== [[" in result
+    assert "==== Coordinate" in result
     assert "===== Members" in result
 
 
@@ -422,7 +423,8 @@ def test_link_from_proxy_stores_stack_trace_with_proxy_name(preprocessing_api, c
     document.original_file.touch()
     include_doc = document.with_relative_path("include.adoc")
     include_doc.original_file.write_text("""${api.link_class("asciidoxy::geometry::Coordinate")}""")
-    preprocessing_api.include(include_doc.relative_path.name)
+    with pytest.warns(FutureWarning):
+        preprocessing_api.include(include_doc.relative_path.name)
 
     assert "cpp-classasciidoxy_1_1geometry_1_1_coordinate" in context.linked
     traces = context.linked["cpp-classasciidoxy_1_1geometry_1_1_coordinate"]
@@ -791,7 +793,7 @@ def test_anchor(file_builder, tdb_single_and_multipage):
         if isinstance(api, PreprocessingApi):
             assert result == ""
         else:
-            assert result == "[[my-anchor,anchor text]]"
+            assert result == "[#my-anchor,reftext='anchor text']"
 
 
 def test_anchor__no_link_text(file_builder, tdb_single_and_multipage):
@@ -802,7 +804,7 @@ def test_anchor__no_link_text(file_builder, tdb_single_and_multipage):
         if isinstance(api, PreprocessingApi):
             assert result == ""
         else:
-            assert result == "[[my-anchor]]"
+            assert result == "[#my-anchor]"
 
 
 def test_cross_document_ref__flexible_anchor__same_package(file_builder, tdb_single_and_multipage):
@@ -896,7 +898,7 @@ def test_include__relative_path(file_builder):
         lines = result.splitlines()
         assert len(lines) == 2
 
-        assert lines[0] == "[[top-includes-another_file-top]]"
+        assert lines[0] == "[#top-includes-another_file-top]"
 
         assert lines[1].startswith("include::")
         assert lines[1].endswith("[leveloffset=+1]")
@@ -916,7 +918,7 @@ def test_include__relative_path__parent_directory(file_builder):
         lines = result.splitlines()
         assert len(lines) == 2
 
-        assert lines[0] == "[[top-includes-another_file-top]]"
+        assert lines[0] == "[#top-includes-another_file-top]"
 
         assert lines[1].startswith("include::")
         assert lines[1].endswith("[leveloffset=+1]")
@@ -956,7 +958,7 @@ def test_include__from_package(file_builder):
         lines = result.splitlines()
         assert len(lines) == 2
 
-        assert lines[0] == "[[top-another_file-top]]"
+        assert lines[0] == "[#top-another_file-top]"
 
         assert lines[1].startswith("include::")
         assert lines[1].endswith("[leveloffset=+1]")
@@ -983,7 +985,7 @@ ${include("yet_another_file.adoc")}
         lines = result.splitlines()
         assert len(lines) == 2
 
-        assert lines[0] == "[[top-another_file-top]]"
+        assert lines[0] == "[#top-another_file-top]"
 
         assert lines[1].startswith("include::")
         assert lines[1].endswith("[leveloffset=+1]")
@@ -1029,7 +1031,7 @@ def test_include__direct_access_to_other_package_for_old_style_packages(file_bui
         lines = result.splitlines()
         assert len(lines) == 2
 
-        assert lines[0] == "[[top-another_file-top]]"
+        assert lines[0] == "[#top-another_file-top]"
 
         assert lines[1].startswith("include::")
         assert lines[1].endswith("[leveloffset=+1]")
@@ -1220,11 +1222,94 @@ ${include("third.adoc", always_embed=True)}""")
         assert len(third_doc.children) == 0
 
 
+def test_include__duplicate_include(file_builder, tdb_warnings_are_and_are_not_errors):
+    file_builder.add_input_file("input.adoc")
+    file_builder.add_package_file("package-a", "another_file.adoc", register=False)
+
+    for api in file_builder.apis():
+        api.include("another_file.adoc", package_name="package-a")
+        if tdb_warnings_are_and_are_not_errors and isinstance(api, PreprocessingApi):
+            with pytest.raises(DuplicateIncludeError):
+                api.include("another_file.adoc", package_name="package-a")
+        else:
+            api.include("another_file.adoc", package_name="package-a")
+
+
+def test_include__embed_and_include(file_builder, tdb_warnings_are_and_are_not_errors):
+    file_builder.add_input_file("input.adoc")
+    file_builder.add_package_file("package-a", "another_file.adoc", register=False)
+
+    for api in file_builder.apis():
+        api.include("another_file.adoc", package_name="package-a", always_embed=True)
+        if tdb_warnings_are_and_are_not_errors and isinstance(api, PreprocessingApi):
+            with pytest.raises(DuplicateIncludeError):
+                api.include("another_file.adoc", package_name="package-a")
+        else:
+            api.include("another_file.adoc", package_name="package-a")
+
+
+def test_include__include_and_embed(file_builder, tdb_warnings_are_and_are_not_errors):
+    file_builder.add_input_file("input.adoc")
+    file_builder.add_package_file("package-a", "another_file.adoc", register=False)
+
+    for api in file_builder.apis():
+        api.include("another_file.adoc", package_name="package-a")
+        if tdb_warnings_are_and_are_not_errors and isinstance(api, PreprocessingApi):
+            with pytest.raises(DuplicateIncludeError):
+                api.include("another_file.adoc", package_name="package-a", always_embed=True)
+        else:
+            api.include("another_file.adoc", package_name="package-a", always_embed=True)
+
+
+def test_include__duplicate_embed(file_builder, tdb_warnings_are_and_are_not_errors):
+    file_builder.add_input_file("input.adoc")
+    file_builder.add_package_file("package-a", "another_file.adoc", register=False)
+
+    for api in file_builder.apis():
+        api.include("another_file.adoc", package_name="package-a", always_embed=True)
+        api.include("another_file.adoc", package_name="package-a", always_embed=True)
+
+
 def test_multipage_toc__default(generating_api, document, multipage):
     result = generating_api.multipage_toc()
-    assert result == ":docinfo: private"
+    assert result == """\
+:docinfo: private
+:stylesheet: asciidoxy-toc-left.css"""
 
     assert document.docinfo_footer_file.is_file()
+    assert document.stylesheet == "asciidoxy-toc-left.css"
+
+
+def test_multipage_toc__left(generating_api, document, multipage):
+    result = generating_api.multipage_toc(side="left")
+    assert result == """\
+:docinfo: private
+:stylesheet: asciidoxy-toc-left.css"""
+
+    assert document.docinfo_footer_file.is_file()
+    assert document.stylesheet == "asciidoxy-toc-left.css"
+
+
+def test_multipage_toc__right(generating_api, document, multipage):
+    result = generating_api.multipage_toc(side="right")
+    assert result == """\
+:docinfo: private
+:stylesheet: asciidoxy-toc-right.css"""
+
+    assert document.docinfo_footer_file.is_file()
+    assert document.stylesheet == "asciidoxy-toc-right.css"
+
+
+def test_multipage_toc__in_subdir(context, generating_api, document, multipage):
+    context.document = document.with_relative_path("dir/subdir/document.adoc")
+    context.document.work_file.parent.mkdir(parents=True)
+    result = generating_api.multipage_toc()
+    assert result == """\
+:docinfo: private
+:stylesheet: ../../asciidoxy-toc-left.css"""
+
+    assert context.document.docinfo_footer_file.is_file()
+    assert context.document.stylesheet == "asciidoxy-toc-left.css"
 
 
 def test_multipage_toc__multipage_off(generating_api, document):
@@ -1262,6 +1347,8 @@ def test_process_adoc_single_file(warnings_are_errors, test_file_name, single_an
                               config=default_config,
                               progress=progress_mock)[0]
     assert output_doc.work_file.is_file()
+    assert output_doc.stylesheet == "asciidoxy-no-toc.css"
+    assert output_doc.stylesheet_file.is_file()
 
     content = output_doc.work_file.read_text()
     if update_expected_results:
@@ -1288,6 +1375,8 @@ def test_process_adoc_multi_file(single_and_multipage, api_reference, package_ma
     assert len(output_docs) == 3
     for doc in output_docs:
         assert doc.work_file.is_file()
+        assert doc.stylesheet == "asciidoxy-no-toc.css"
+        assert doc.stylesheet_file.is_file()
         expected_output_file = adoc_data_expected_result_file(doc.work_file, single_and_multipage,
                                                               doxygen_version)
         expected_output_file = adoc_data / expected_output_file.relative_to(main_doc.work_dir)
@@ -1463,7 +1552,8 @@ def test_require_version__exact_match(preprocessing_api):
 
 
 def test_require_version__exact_match__fail(preprocessing_api):
-    version_parts = __version__.split(".")
+    base_version, _, _ = __version__.partition("-")
+    version_parts = base_version.split(".")
     version_parts[2] = str(int(version_parts[2]) + 1)
     version = ".".join(version_parts)
     with pytest.raises(IncompatibleVersionError):
@@ -1549,8 +1639,10 @@ def test_context_link_to_element_element_not_inserted(context, single_and_multip
 
 def test_api_proxy__filter(generating_api):
     api = ApiProxy(generating_api)
-    api.filter(members="-SharedData")
-    result = api.insert("asciidoxy::traffic::TrafficEvent")
+    with pytest.warns(FutureWarning):
+        api.filter(members="-SharedData")
+    with pytest.warns(FutureWarning):
+        result = api.insert("asciidoxy::traffic::TrafficEvent")
     assert "SharedData" not in result
     assert "Update" in result
     assert "CalculateDelay" in result
@@ -1558,25 +1650,29 @@ def test_api_proxy__filter(generating_api):
 
 def test_api_proxy__insert(generating_api):
     api = ApiProxy(generating_api)
-    result = api.insert("asciidoxy::geometry::Coordinate")
+    with pytest.warns(FutureWarning):
+        result = api.insert("asciidoxy::geometry::Coordinate")
     assert "class asciidoxy::geometry::Coordinate" in result
 
 
 def test_api_proxy__insert_class(generating_api):
     api = ApiProxy(generating_api)
-    result = api.insert_class("asciidoxy::geometry::Coordinate")
+    with pytest.warns(FutureWarning):
+        result = api.insert_class("asciidoxy::geometry::Coordinate")
     assert "class asciidoxy::geometry::Coordinate" in result
 
 
 def test_api_proxy__link(generating_api):
     api = ApiProxy(generating_api)
-    result = api.link("asciidoxy::geometry::Coordinate")
+    with pytest.warns(FutureWarning):
+        result = api.link("asciidoxy::geometry::Coordinate")
     assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[++Coordinate++]")
 
 
 def test_api_proxy__link_class(generating_api):
     api = ApiProxy(generating_api)
-    result = api.link_class("asciidoxy::geometry::Coordinate")
+    with pytest.warns(FutureWarning):
+        result = api.link_class("asciidoxy::geometry::Coordinate")
     assert result == ("xref:cpp-classasciidoxy_1_1geometry_1_1_coordinate[++Coordinate++]")
 
 
@@ -1586,7 +1682,8 @@ def test_api_proxy__cross_document_ref(file_builder, tdb_single_and_multipage):
 
     for api in file_builder.apis():
         proxy = ApiProxy(api)
-        result = proxy.cross_document_ref("includes/other_file.adoc", anchor="anchor")
+        with pytest.warns(FutureWarning):
+            result = proxy.cross_document_ref("includes/other_file.adoc", anchor="anchor")
         if isinstance(api, GeneratingApi):
             assert result == "<<includes/other_file.adoc#anchor,anchor>>"
 
@@ -1597,7 +1694,8 @@ def test_api_proxy__cross_document_ref__old_syntax(file_builder, tdb_single_and_
 
     for api in file_builder.apis():
         proxy = ApiProxy(api)
-        result = proxy.cross_document_ref("includes/other_file.adoc", "anchor")
+        with pytest.warns(FutureWarning):
+            result = proxy.cross_document_ref("includes/other_file.adoc", "anchor")
         if isinstance(api, GeneratingApi):
             assert result == "<<includes/other_file.adoc#anchor,anchor>>"
 
@@ -1608,11 +1706,12 @@ def test_api_proxy__include(file_builder):
 
     for api in file_builder.apis():
         proxy = ApiProxy(api)
-        result = proxy.include("includes/another_file.adoc")
+        with pytest.warns(FutureWarning):
+            result = proxy.include("includes/another_file.adoc")
         lines = result.splitlines()
         assert len(lines) == 2
 
-        assert lines[0] == "[[top-includes-another_file-top]]"
+        assert lines[0] == "[#top-includes-another_file-top]"
 
         assert lines[1].startswith("include::")
         assert lines[1].endswith("[leveloffset=+1]")
@@ -1629,11 +1728,12 @@ def test_api_proxy__include__old_syntax(file_builder):
 
     for api in file_builder.apis():
         proxy = ApiProxy(api)
-        result = proxy.include("includes/another_file.adoc", "+2")
+        with pytest.warns(FutureWarning):
+            result = proxy.include("includes/another_file.adoc", "+2")
         lines = result.splitlines()
         assert len(lines) == 2
 
-        assert lines[0] == "[[top-includes-another_file-top]]"
+        assert lines[0] == "[#top-includes-another_file-top]"
 
         assert lines[1].startswith("include::")
         assert lines[1].endswith("[leveloffset=+2]")
@@ -1650,24 +1750,32 @@ def test_api_proxy__language(generating_api):
     assert len(exception.value.candidates) == 2
 
     api = ApiProxy(generating_api)
-    api.language("java")
+    with pytest.warns(FutureWarning):
+        api.language("java")
     result = generating_api.insert("Logger")
     assert "class Logger" in result
 
 
 def test_api_proxy__namespace(generating_api):
     api = ApiProxy(generating_api)
-    api.namespace("asciidoxy::geometry::")
-    result = api.insert("Coordinate", lang="cpp")
+    with pytest.warns(FutureWarning):
+        api.namespace("asciidoxy::geometry::")
+    with pytest.warns(FutureWarning):
+        result = api.insert("Coordinate", lang="cpp")
     assert "class asciidoxy::geometry::Coordinate" in result
 
 
 def test_api_proxy__require_version(preprocessing_api):
-    ApiProxy(preprocessing_api).require_version(f"=={__version__}")
+    with pytest.warns(FutureWarning):
+        ApiProxy(preprocessing_api).require_version(f"=={__version__}")
 
 
 def test_api_proxy__multipage_toc(generating_api, document, multipage):
-    result = generating_api.multipage_toc()
-    assert result == ":docinfo: private"
+    api = ApiProxy(generating_api)
+    with pytest.warns(FutureWarning):
+        result = api.multipage_toc()
+    assert result == """\
+:docinfo: private
+:stylesheet: asciidoxy-toc-left.css"""
 
     assert document.docinfo_footer_file.is_file()
